==> goblin-2.4a3.tgz: include/goblin.2.4/genincl.h <==

/*
**  This file forms part of the GOBLIN C++ Class Library.
**
**  Written by Christian Fremuth-Paeger, October 2000.
**  
**  Copying, compiling, distribution and modification
**  of this source code is permitted only in accordance
**  with the GOBLIN general licence information.
*/             



    TCap            UCap(TArc a) throw(ERRange)
                        {return X.UCap(a);};
    void            SetUCap(TArc a,TCap uu) throw(ERRange)
                        {X.SetUCap(a,uu);};
    void            SetCUCap(TCap uu) throw(ERRange)
                        {X.SetCUCap(uu);};
    TCap            MaxUCap() throw()
                        {return X.MaxUCap();};
    char            CUCap() throw()
                        {return X.CUCap();};
    TCap            LCap(TArc a) throw(ERRange)
                        {return X.LCap(a);};
    void            SetLCap(TArc a,TCap ll) throw(ERRange)
                        {X.SetLCap(a,ll);};
    void            SetCLCap(TCap ll) throw(ERRange)
                        {X.SetCLCap(ll);};
    TCap            MaxLCap() throw()
                        {return X.MaxLCap();};
    char            CLCap() throw()
                        {return X.CLCap();};
    TCap            Demand(TNode v) throw(ERRange)
                        {return X.Demand(v);};
    void            SetDemand(TNode v,TCap bb) throw(ERRange)
                        {X.SetDemand(v,bb);};
    void            SetCDemand(TCap bb) throw()
                        {X.SetCDemand(bb);};
    TCap            MaxDemand() throw()
                        {return X.MaxDemand();};
    char            CDemand() throw()
                        {return X.CDemand();};
    
    char            Dim() throw()
                        {return X.Dim();};     
    TFloat          C(TNode v,char i) throw(ERRange)
                        {return X.C(v,i);};     
    void            SetC(TNode v,char i,TFloat xx) throw(ERRange)
                        {X.SetC(v,i,xx);};
    TFloat          CMax(char i) throw()
                        {return X.CMax(i);};     

    void            SetLength(TArc a,TFloat ll) throw(ERRange)
                        {X.SetLength(a,ll);};     
    void            SetCLength(TFloat ll) throw()
                        {X.SetCLength(ll);};     
    TFloat          MaxLength() throw()
                        {return X.MaxLength();};     
    char            CLength() throw()
                        {return X.CLength();};

    char            Orientation(TArc a) throw(ERRange)
                        {return X.Orientation(a);};
    char            Orientation() throw()
                        {return X.Orientation();};     
    char            COrientation() throw()
                        {return X.COrientation();};
    char            Blocking(TArc a) throw(ERRange)
                        {return X.Blocking(a);};
    
    void            NewSubgraph() throw(ERRejected)
                        {X.NewSubgraph();};
    void            ReleaseSubgraph() throw()
                        {X.ReleaseSubgraph();};

    TFloat          Sub(TArc a) throw(ERRange)
                        {return X.Sub(a);};
    void            AddArc(TArc a,TFloat Lambda) throw(ERRange)
                        {X.AddArc(a,Lambda);};
    void            OmitArc(TArc a,TFloat Lambda) throw(ERRange)
                        {X.OmitArc(a,Lambda);};

==> goblin-2.6.4.tgz: include/goblin.2.6/genincl.h <==

/*
**  This file forms part of the GOBLIN C++ Class Library.
**
**  Written by Christian Fremuth-Paeger, October 2000.
**  
**  Copying, compiling, distribution and modification
**  of this source code is permitted only in accordance
**  with the GOBLIN general licence information.
*/             



    TCap            UCap(TArc a) throw(ERRange)
                        {return X.UCap(a);};
    void            SetUCap(TArc a,TCap uu) throw(ERRange)
                        {X.SetUCap(a,uu);};
    void            SetCUCap(TCap uu) throw(ERRange)
                        {X.SetCUCap(uu);};
    TCap            MaxUCap() throw()
                        {return X.MaxUCap();};
    bool            CUCap() throw()
                        {return X.CUCap();};
    TCap            LCap(TArc a) throw(ERRange)
                        {return X.LCap(a);};
    void            SetLCap(TArc a,TCap ll) throw(ERRange)
                        {X.SetLCap(a,ll);};
    void            SetCLCap(TCap ll) throw(ERRange)
                        {X.SetCLCap(ll);};
    TCap            MaxLCap() throw()
                        {return X.MaxLCap();};
    bool            CLCap() throw()
                        {return X.CLCap();};
    TCap            Demand(TNode v) throw(ERRange)
                        {return X.Demand(v);};
    void            SetDemand(TNode v,TCap bb) throw(ERRange)
                        {X.SetDemand(v,bb);};
    void            SetCDemand(TCap bb) throw()
                        {X.SetCDemand(bb);};
    TCap            MaxDemand() throw()
                        {return X.MaxDemand();};
    bool            CDemand() throw()
                        {return X.CDemand();};
    
    char            Dim() throw()
                        {return X.Dim();};     
    TFloat          C(TNode v,char i) throw(ERRange)
                        {return X.C(v,i);};     
    void            SetC(TNode v,char i,TFloat xx) throw(ERRange)
                        {X.SetC(v,i,xx);};
    TFloat          CMax(char i) throw()
                        {return X.CMax(i);};     

    void            SetLength(TArc a,TFloat ll) throw(ERRange)
                        {X.SetLength(a,ll);};     
    void            SetCLength(TFloat ll) throw()
                        {X.SetCLength(ll);};     
    TFloat          MaxLength() throw()
                        {return X.MaxLength();};     
    bool            CLength() throw()
                        {return X.CLength();};

    char            Orientation(TArc a) throw(ERRange)
                        {return X.Orientation(a);};
    char            Orientation() throw()
                        {return X.Orientation();};     
    bool            COrientation() throw()
                        {return X.COrientation();};
    bool            Blocking(TArc a) throw(ERRange)
                        {return X.Blocking(a);};
    
    void            NewSubgraph() throw(ERRejected)
                        {X.NewSubgraph();};
    void            ReleaseSubgraph() throw()
                        {X.ReleaseSubgraph();};

    TFloat          Sub(TArc a) throw(ERRange)
                        {return X.Sub(a);};
    void            AddArc(TArc a,TFloat Lambda) throw(ERRange)
                        {X.AddArc(a,Lambda);};
    void            OmitArc(TArc a,TFloat Lambda) throw(ERRange)
                        {X.OmitArc(a,Lambda);};
